@@ -3,7 +3,7 @@ use strict;
 use warnings;
 no warnings 'redefine';
 
-our $VERSION = do { my @r = ( q$Revision: 2.9 $ =~ /\d+/g ); sprintf "%d." . "%02d" x $#r, @r };
+our $VERSION = do { my @r = ( q$Revision: 2.10 $ =~ /\d+/g ); sprintf "%d." . "%02d" x $#r, @r };
 use Encode qw(find_encoding encode_utf8 decode_utf8);
 use MIME::Base64;
 use Carp;
@@ -175,9 +175,9 @@ sub _encode_q {
     my $chunk = shift;
     $chunk = encode_utf8($chunk);
     $chunk =~ s{
-            [^0-9A-Za-z]
+	   ([^0-9A-Za-z])
        }{
-            join("" => map {sprintf "=%02X", $_} unpack("C*", $&))
+            join("" => map {sprintf "=%02X", $_} unpack("C*", $1))
        }egox;
     return HEAD . 'Q?' . $chunk . TAIL;
 }
